@@ -734,6 +734,9 @@ class Printer(BasePrinter):
         """
         assert isinstance(t, ast.ListExpr)
         in_one_line = len(set(map(lambda e: e.line, t.elts))) <= 1
+        if len(t.elts or []) > 0:
+            if isinstance(t.elts[0], ast.ListIfItemExpr):
+                in_one_line = False
         self.write(ast.TokenValue.LEFT_BRACKETS)
         if t.elts:
             self.print(Indentation.IndentWithNewline if not in_one_line else "")
