@@ -50,6 +50,14 @@ def debug_names(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
     return vm.debug_names(idx, at)
 
 
+def push_frame_locals(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
+    vm.push_frame_locals()
+
+
+def pop_frame_locals(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
+    vm.pop_frame_locals()
+
+
 def unpack_operand(arg: int):
     return int(arg & 0xFF), int((arg >> 8) & 0xFF), int((arg >> 16) & 0xFF)
 
@@ -92,20 +100,35 @@ def bin_true_divide(vm, code: int, arg: int) -> Optional[obj.KCLObject]:
 
 
 def build_map(vm, _code: int, _arg: int) -> Optional[obj.KCLObject]:
-    dict_obj = obj.KCLDictObject(value={})
-    vm.push(dict_obj)
-    return dict_obj
+    config_obj = obj.KCLSchemaConfigObject(value={})
+    vm.push(config_obj)
+    return config_obj
 
 
 def load_free(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
+    name = vm.names[arg]
+
+    # If the variable in local:
+    if vm.ctx.locals_list:
+        index = len(vm.ctx.locals_list) - 1
+        while index >= 0:
+            if name in vm.ctx.locals_list[index]:
+                vm.push(vm.ctx.locals_list[index][name])
+                return vm.ctx.locals_list[index][name]
+            index -= 1
+
+    if name in vm.ctx.locals:
+        vm.push(vm.ctx.locals[name])
+        return vm.ctx.locals[name]
+
     free_obj = obj.NONE_INSTANCE
     index = vm.frame_index
-    name = vm.names[arg]
     # Search the local variables from the inside to the outside schema
     while index >= 1:
         index -= 1
         if name in vm.frames[index].locals:
             free_obj = vm.frames[index].locals[name]
+
     vm.push(free_obj)
     return free_obj
 
@@ -756,6 +779,7 @@ def map_add(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
         config_ref.insert_with(data_obj, -1)
     else:
         config_ref.update(data_obj)
+    config_ref.add_operation(key.value, operation)
     return config_ref
 
 
@@ -876,11 +900,14 @@ def build_schema(vm, _code: int, arg: int) -> Optional[obj.KCLObject]:
     schema_obj = vm.pop()
     config_obj = vm.pop()
     config_meta = obj.to_python_obj(vm.pop())
+    finalize = vm.pop().value
     args, kwargs = _evaluator_inst.call_vars_and_keywords(arg, vm)
     # Schema type object
     if isinstance(schema_obj, obj.KCLSchemaTypeObject):
         if isinstance(config_obj, obj.KCLDictObject):
-            inst = schema_obj.new_instance(config_obj, config_meta, args, kwargs, vm)
+            inst = schema_obj.new_instance(
+                config_obj, config_meta, args, kwargs, vm, finalize=finalize
+            )
         else:
             inst = config_obj
     # Schema value object
@@ -1081,6 +1108,8 @@ VM_OP_ACTIONS = {
     Opcode.SCHEMA_NOP: schema_nop,
     Opcode.FORMAT_VALUES: format_values,
     Opcode.MEMBER_SHIP_AS: member_ship_as,
+    Opcode.PUSH_FRAME_LOCALS: push_frame_locals,
+    Opcode.POP_FRAME_LOCALS: pop_frame_locals,
     Opcode.DEBUG_STACK: debug_stack,
     Opcode.DEBUG_LOCALS: debug_locals,
     Opcode.DEBUG_GLOBALS: debug_globals,
